[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- pygeodesy: A pure Python implementation of geodesy tools for various ellipsoidal and spherical earth models using precision exact, elliptic, trigonometric, vector-based, iterative and approximate methods for geodetic (lat-/longitude), geocentric (ECEF cartesian), local (LTP) and certain triaxial ellipsoidal coordinates.
  - pygeodesy.__main__: Print pygeodesy version, etc.
  - pygeodesy.albers: Albers Equal-Area projections.
  - pygeodesy.angles: Classes Ang, Deg, Rad and Lambertian accurately representing an angle as a 3-tuple `(sine, cosine, turns)`, with `turns` the number of full turns.
  - pygeodesy.auxilats: Classes AuxAngle, AuxDLat, AuxDST and AuxLat transcoded to Python from Karney's C++ class AuxAngle, DAuxLatitude, DST, repectively AuxLatitude all in GeographicLib version 2.2+.
    - pygeodesy.auxilats._CX_4: Coefficients for `_AUXLATITUDE_ORDER` 4 from Karney's C++ class AuxLatitude transcoded to a Python `_Rdict[auxout][auxin]` of `_Rtuple`s.
    - pygeodesy.auxilats._CX_6: Coefficients for `_AUXLATITUDE_ORDER` 6 from Karney's C++ class AuxLatitude transcoded to a Python `_Rdict[auxout][auxin]` of `_Rtuple`s.
    - pygeodesy.auxilats._CX_8: Coefficients for `_AUXLATITUDE_ORDER` 8 from Karney's C++ class AuxLatitude transcoded to a Python `_Rdict[auxout][auxin]` of `_Rtuple`s.
    - pygeodesy.auxilats._CX_Rs: (INTERNAL) Classes `_Rcoeffs`, `_Rdict` and `_Rtuple` to store the deferred Python versions of coefficients from Karney's C++ class AuxLatitude.
    - pygeodesy.auxilats.__main__: Print auxilats version, etc.
    - pygeodesy.auxilats.auxAngle: (INTERNAL) Auxiliary latitudes' base classes, constants and functions.
    - pygeodesy.auxilats.auxDLat: Class AuxDLat transcoded to Python from Karney's C++ class DAuxLatitude in GeographicLib version 2.2+.
    - pygeodesy.auxilats.auxDST: Discrete Sine Transforms (AuxDST) in Python, transcoded from Karney's C++ class DST in GeographicLib version 2.2+.
    - pygeodesy.auxilats.auxLat: Class AuxLat transcoded to Python from Karney's C++ class AuxLatitude in GeographicLib version 2.2+.
    - pygeodesy.auxilats.auxily: (INTERNAL) Auxiliary latitudes' classes, constants and functions.
  - pygeodesy.azimuthal: Equidistant, Equal-Area, and other Azimuthal projections.
  - pygeodesy.basics: Some, basic definitions, functions and dependencies.
  - pygeodesy.booleans: Boolean operations on composite polygons and clips.
  - pygeodesy.cartesianBase: (INTERNAL) Private `CartesianBase` class for elliposiodal, spherical and N-/vectorial `Cartesian`s and public functions rtp2xyz, rtp2xyz_, xyz2rtp and xyz2rtp_.
  - pygeodesy.clipy: Clip a path or polygon of `LatLon` points against a rectangular box or an arbitrary (convex) region.
  - pygeodesy.constants: Single-instance `float` and `int` constants across `pygeodesy` modules and related functions pygeodesy.float_, pygeodesy.float0_, pygeodesy.isclose, pygeodesy.isfinite, pygeodesy.isinf, pygeodesy.isint0, pygeodesy.isnan, pygeodesy.isnear0, pygeodesy.isnear1, pygeodesy.isnear90, pygeodesy.isneg0, pygeodesy.isninf, pygeodesy.isnon0 and pygeodesy.remainder.
  - pygeodesy.css: Cassini-Soldner (CSS) projection.
  - pygeodesy.datums: Datums and transformations thereof.
  - pygeodesy.deprecated: DEPRECATED classes, constants, functions, interns, methods, etc.
    - pygeodesy.deprecated.bases: DEPRECATED on 2021.02.10, use (INTERNAL) module pygeodesy.latlonBase instead.
    - pygeodesy.deprecated.classes: DEPRECATED classes kept for backward compatibility.
    - pygeodesy.deprecated.consterns: DEPRECATED constants, interns and singletons kept for backward compatibility.
    - pygeodesy.deprecated.datum: DEPRECATED on 2022.09.12, use module pygeodesy.datums or pygeodesy.ellipsoids instead.
    - pygeodesy.deprecated.functions: DEPRECATED functions kept for backward compatibility.
    - pygeodesy.deprecated.nvector: DEPRECATED on 2021.05.20, use (INTERNAL) module pygeodesy.nvectorBase instead.
    - pygeodesy.deprecated.rhumbBase: DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.bases instead.
    - pygeodesy.deprecated.rhumbaux: DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.aux_ instead.
    - pygeodesy.deprecated.rhumbsolve: DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.solve instead.
    - pygeodesy.deprecated.rhumbx: DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.ekx instead.
  - pygeodesy.dms: Parsers and formatters of angles in degrees, minutes and seconds or radians.
  - pygeodesy.ecef: Geocentric Earth-Centered, Earth-Fixed (ECEF) coordinates.
  - pygeodesy.ecefLocals: (INTERNAL) ECEF to local coodinate conversions, separated from module `ecef` to defer importing the latter into `CartesianBase` and `LatLonBase`.
  - pygeodesy.elevations: Web-services-based elevations and `CONUS` geoid heights.
  - pygeodesy.ellipses: Class `Ellipse` for 2-D ellipse attributes, like perimeter, area, etc.
  - pygeodesy.ellipsoidalBase: (INTERNAL) Private ellipsoidal base classes `CartesianEllipsoidalBase` and `LatLonEllipsoidalBase`.
  - pygeodesy.ellipsoidalBaseDI: (INTERNAL) Private, ellipsoidal Direct/Inverse geodesy base class `LatLonEllipsoidalBaseDI` and functions.
  - pygeodesy.ellipsoidalExact: Exact ellipsoidal geodesy using Karney's Exact Geodesic.
  - pygeodesy.ellipsoidalGeodSolve: Exact ellipsoidal geodesy, intended for testing purposes only.
  - pygeodesy.ellipsoidalKarney: Ellipsoidal, Karney-based geodesy.
  - pygeodesy.ellipsoidalNvector: Ellipsoidal, `N-vector`-based geodesy.
  - pygeodesy.ellipsoidalVincenty: Ellipsoidal, Vincenty-based geodesy.
  - pygeodesy.ellipsoids: Ellipsoidal and spherical earth models.
  - pygeodesy.elliptic: Karney's elliptic integrals and elliptic functions in pure Python.
  - pygeodesy.epsg: European Petroleum Survey Group (EPSG) en-/decoding.
  - pygeodesy.errors: Errors, exceptions, exception formatting and exception chaining.
  - pygeodesy.etm: A pure Python version of Karney's `Exact Transverse Mercator` (ETM) projection.
  - pygeodesy.fmath: Utilities for precision floating point summation, multiplication, `fused-multiply-add`, polynomials, roots, etc.
  - pygeodesy.formy: Formulary of basic geodesy functions and approximations.
  - pygeodesy.frechet: Fréchet distances.
  - pygeodesy.fstats: Classes for running statistics and regressions based on pygeodesy.Fsum, precision floating point summation and accurate multiplication.
  - pygeodesy.fsums: Class Fsum for precision floating point summation similar to Python's `math.fsum`, but enhanced with precision running summation plus optionally, accurate TwoProduct multiplication.
  - pygeodesy.gars: Global Area Reference System (GARS) en-/decoding.
  - pygeodesy.geod3solve: Wrapper to invoke Karney's Geod3Solve utility as a `triaxial` geodesic, but intended mainly for testing purposes.
  - pygeodesy.geodesici: Classes Intersectool and Intersector to find the intersections of two geodesic lines or line segments.
  - pygeodesy.geodesicw: Wrapper around Python classes `geodesic.Geodesic` and `geodesicline.GeodesicLine` from Karney's Python package geographiclib, provided that package is installed.
  - pygeodesy.geodesicx: A pure Python version of Karney's C++ classes GeodesicExact and GeodesicLineExact.
    - pygeodesy.geodesicx._C4_24: A Python version of part of Karney's C++ module GeodesicExactC4.
    - pygeodesy.geodesicx._C4_27: A Python version of part of Karney's C++ module GeodesicExactC4.
    - pygeodesy.geodesicx._C4_30: A Python version of part of Karney's C++ module GeodesicExactC4.
    - pygeodesy.geodesicx.__main__: Print geodesicx version, etc.
    - pygeodesy.geodesicx.gx: A pure Python version of Karney's C++ class GeodesicExact.
    - pygeodesy.geodesicx.gxarea: Slightly enhanced versions of classes PolygonArea and `Accumulator` from Karney's Python geographiclib.
    - pygeodesy.geodesicx.gxbases: (INTERNAL) Private geodesicx base class, functions and constants.
    - pygeodesy.geodesicx.gxline: A pure Python version of Karney's C++ class GeodesicLineExact.
  - pygeodesy.geodsolve: Wrapper to invoke Karney's GeodSolve utility as an (exact) geodesic, but intended mainly for testing purposes.
  - pygeodesy.geohash: Gustavo Niemeyer’s Geohash.
  - pygeodesy.geoids: Geoid models and geoid height interpolations.
  - pygeodesy.hausdorff: Hausdorff distances.
  - pygeodesy.heights: Height interpolations at `LatLon` points from known `knots`.
  - pygeodesy.internals: Mostly INTERNAL functions, except machine, print_ and printf.
  - pygeodesy.interns: Single `str`ing constants, `intern`'ed across `pygeodesy` modules and function pygeodesy.machine.
  - pygeodesy.iters: Iterators with options.
  - pygeodesy.karney: Wrapper around several `geomath.Math` functions from Karney's Python package geographiclib, provided that package is installed.
  - pygeodesy.ktm: A pure Python version of Karney's C++ class TransverseMercator based on Krüger series.
  - pygeodesy.latlonBase: (INTERNAL) Base class LatLonBase for all elliposiodal, spherical and N-vectorial `LatLon` classes.
  - pygeodesy.lazily: Lazily import `pygeodesy` modules and attributes, based on lazy_import from Brett Cannon's modutil.
  - pygeodesy.lcc: Lambert Conformal Conic (LCC) projection.
  - pygeodesy.ltp: Local Tangent Plane (LTP) and local cartesian coordinates.
  - pygeodesy.ltpTuples: Named, Local Tangent Plane (LTP) tuples.
  - pygeodesy.mgrs: Military Grid Reference System (MGRS/NATO) references.
  - pygeodesy.named: (INTERNAL) Nameable class instances.
  - pygeodesy.namedTuples: Named tuples.
  - pygeodesy.nvectorBase: (INTERNAL) Private elliposiodal and spherical `Nvector` base classes LatLonNvectorBase and NvectorBase and function sumOf.
  - pygeodesy.osgr: Ordnance Survey Grid References (OSGR) references on the UK National Grid.
  - pygeodesy.points: Utilities for point lists, tuples, etc.
  - pygeodesy.props: Mutable, immutable and caching/memoizing properties and deprecation decorators.
  - pygeodesy.resections: 3-Point resection functions cassini, collins5, pierlot, pierlotx and tienstra7, survey functions snellius3 and wildberger3 and triangle functions triAngle, triAngle5, triSide, triSide2 and triSide4.
  - pygeodesy.rhumb: Package of lazily imported `rhumb` modules rhumb.aux_, rhumb.ekx and rhumb.solve.
    - pygeodesy.rhumb.aux_: A pure Python version of Karney's Auxiliary Latitudes, C++ classes Rhumb and RhumbLine from GeographicLib version 2.2+ renamed to RhumbAux respectively RhumbLineAux.
    - pygeodesy.rhumb.bases: (INTERNAL) base classes `RhumbBase` and `RhumbLineBase`, pure Python version of Karney's C++ classes Rhumb and RhumbLine from GeographicLib versions 2.0 and 2.2 and Karney's C++ example Rhumb intersect.
    - pygeodesy.rhumb.ekx: A pure Python version of Karney's elliptic functions, Krüger series expansion, C++ classes Rhumb and and RhumbLine from GeographicLib version 2.0, kept for backward compatibility.
    - pygeodesy.rhumb.solve: Wrapper to invoke Karney's RhumbSolve utility as an (exact) rhumb or rhumb line from either GeographicLib 2.0 or 2.2+.
  - pygeodesy.simplify: Simplify or linearize a path of `LatLon` points.
  - pygeodesy.solveBase: (INTERNAL) Private base classes for pygeodesy.geodsolve and pygeodesy.rhumb.solve.
  - pygeodesy.sphericalBase: (INTERNAL) Private spherical base classes `CartesianSphericalBase` and `LatLonSphericalBase` for sphericalNvector and sphericalTrigonometry.
  - pygeodesy.sphericalNvector: Spherical, `N-vector`-based geodesy.
  - pygeodesy.sphericalTrigonometry: Spherical, `trigonometry`-based geodesy.
  - pygeodesy.streprs: Floating point and other formatting utilities.
  - pygeodesy.trf: Veness' Terrestrial Reference Frames (TRF), classes RefFrame, registry RefFrames and TRFError.
  - pygeodesy.triaxials: Package of lazily imported modules triaxials.conformal3, triaxials.triaxial3 and triaxials.triaxial5 for triaxial ellipsoids.
    - pygeodesy.triaxials.bases: (INTERNAL) Base classes for ordered triaxial ellipsoid classes Conformal, Conformal3, Triaxial, Triaxial3 and unordered Triaxial_.
    - pygeodesy.triaxials.conformal3: Jacobi Conformal projection classes Conformal3, Conformal3B and Conformal3Sphere on triaxial ellipsoids and spheres using Ang, Deg, Rad lat-, longitude, heading and meridian (convergence) angles.
    - pygeodesy.triaxials.triaxial3: Ordered triaxial ellipsoid classes Triaxial3 and Triaxial3B for conversion between variuos lat-/longitudal and cartesian coordinates on a triaxial ellipsoid using Ang, Deg, Rad lat-, longitude and heading angles.
    - pygeodesy.triaxials.triaxial5: Triaxal ellipsoid classes Triaxial and unordered Triaxial_ and Jacobi conformal projections Conformal and ConformalSphere, transcoded from Karney's GeographicLib 2.5.2 C++ class JacobiConformal to pure Python and miscellaneous classes BetaOmega2Tuple, BetaOmega3Tuple and Conformal2Tuple, all kept for backward copability.
  - pygeodesy.units: Various named units, all sub-classes of `Float`, `Int` or `Str` from basic `float`, `int` respectively `str` to named units as Degrees, Feet, Meter, Radians, etc.
  - pygeodesy.unitsBase: Basic `Float`, `Int` and `Str`ing units classes.
  - pygeodesy.ups: Karney's Universal Polar Stereographic (UPS) projection.
  - pygeodesy.utily: Various utility functions.
  - pygeodesy.utm: Veness' Universal Transverse Mercator (UTM) projection.
  - pygeodesy.utmups: Karney's UTM and UPS utilities.
  - pygeodesy.utmupsBase: (INTERNAL) Private class `UtmUpsBase`, functions and constants for modules epsg, etm, mgrs, ups and utm.
  - pygeodesy.vector2d: 2- or 3-D vectorial functions circin6, circum3, circum4_, iscolinearWith, meeus2, radii11, soddy4, triaxum5 and trilaterate2d2.
  - pygeodesy.vector3d: Extended 3-D vector class Vector3d and functions.
  - pygeodesy.vector3dBase: (INTERNAL) Private, 3-D vector base class `Vector3dBase`.
  - pygeodesy.webmercator: Web Mercator (WM) projection.
  - pygeodesy.wgrs: World Geographic Reference System (WGRS) en-/decoding, aka GEOREF.